==> AGXUnreal-1.17.0_UE-5.6_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/DriveTrain/VelocityRatioGeometryFactorPair.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/DriveTrain/DriveTrainForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics1D/Physics1DForward.h>
#include <openplx/Physics3D/Physics3DForward.h>
/* Generated code for model VelocityRatioGeometryFactorPair */
namespace openplx::DriveTrain {
    /**
     *     The velocity_ratio is found from the turbine velocity divided by the pump velocity.
     *     The counter torque on the impeller of the torque converter is modeled given a
     *     geometry_factor which varies depending on the velocity ratio.
     *     */
    class VelocityRatioGeometryFactorPair : public openplx::Core::Object {
        protected:
            double m_velocity_ratio;
            double m_geometry_factor;

        public:
            VelocityRatioGeometryFactorPair();
            double velocity_ratio() const;
            double geometry_factor() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

==> AGXUnreal-2.1.1_UE-5.5_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/DriveTrain/VelocityRatioGeometryFactorPair.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/DriveTrain/DriveTrainBundleExport.h>
#include <openplx/DriveTrain/DriveTrainForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics1D/Physics1DForward.h>
#include <openplx/Physics3D/Physics3DForward.h>

#ifdef _MSC_VER
#  pragma warning(push)
#  pragma warning(disable: 4251)
#endif

/* Generated code for model VelocityRatioGeometryFactorPair */
namespace openplx::DriveTrain {
    /**
     *     The velocity_ratio is found from the turbine velocity divided by the pump velocity.
     *     The counter torque on the impeller of the torque converter is modeled given a
     *     geometry_factor which varies depending on the velocity ratio.
     *     */
    class OPENPLX_DriveTrain_BUNDLE_EXPORT VelocityRatioGeometryFactorPair : public openplx::Core::Object {
        protected:
            double m_velocity_ratio;
            double m_geometry_factor;

        public:
            VelocityRatioGeometryFactorPair();
            virtual ~VelocityRatioGeometryFactorPair();
            double velocity_ratio() const;
            double geometry_factor() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

#ifdef _MSC_VER
#  pragma warning(pop)
#endif
